@@ -5,9 +5,9 @@ from pathlib import Path
 from typing import Callable
 
 from airflow import DAG
-from airflow.kubernetes.volume import Volume
-from airflow.kubernetes.volume_mount import VolumeMount
+from kubernetes.client.models import V1Volume, V1SecretVolumeSource, V1ConfigMapVolumeSource, V1VolumeMount
 from airflow.contrib.operators.kubernetes_pod_operator import KubernetesPodOperator
+from kubernetes import client
 
 from dataverk_airflow.init_containers import create_git_clone_init_container
 from dataverk_airflow.notifications import create_email_notification, create_slack_notification
@@ -27,7 +27,7 @@ def create_knada_nb_pod_operator(
     slack_channel: str = None,
     branch: str = "master",
     log_output: bool = False,
-    resources: dict = None,
+    resources: client.V1ResourceRequirements = None,
     retries: int = 3,
     extra_envs: dict = None,
     delete_on_finish: bool = True,
@@ -36,6 +36,7 @@ def create_knada_nb_pod_operator(
     do_xcom_push: bool = False,
     on_success_callback: Callable = None,
     nls_lang: str = "NORWEGIAN_NORWAY.AL32UTF8",
+    allowlist: list = [],
 ):
     """ Factory function for creating KubernetesPodOperator for executing knada jupyter notebooks
 
@@ -57,6 +58,7 @@ def create_knada_nb_pod_operator(
     :param do_xcom_push: bool: Whether to push xcom pod output, default False
     :param nls_lang: str: Configure locale and character sets with NLS_LANG environment variable in k8s pod, defaults to Norwegian
     :param on_success_callback: Callable
+    :param allowlist: list: list of hosts and port the task needs to reach on the format host:port
     :return: KubernetesPodOperator
     """
 
@@ -70,17 +72,24 @@ def create_knada_nb_pod_operator(
         "KNADA_TEAM_SECRET": os.environ["KNADA_TEAM_SECRET"]
     }
 
+    allowlist_str = "hooks.slack.com"
+
+    if len(allowlist):
+        allowlist_str += "," + ",".join(allowlist)
+
+    namespace = namespace if namespace else os.getenv("NAMESPACE")
+
     if extra_envs:
         env_vars = dict(env_vars, **extra_envs)
 
     def on_failure(context):
         if email:
-            send_email = create_email_notification(email, name, namespace, dag)
+            send_email = create_email_notification(dag._dag_id, email, name, namespace, dag)
             send_email.execute(context)
 
         if slack_channel:
             slack_notification = create_slack_notification(
-                slack_channel, name, namespace)
+                dag._dag_id, slack_channel, name, namespace)
             slack_notification.execute(context)
 
     return KubernetesPodOperator(
@@ -91,19 +100,27 @@ def create_knada_nb_pod_operator(
         on_failure_callback=on_failure,
         name=name,
         cmds=["/bin/bash", "/execute_notebook.sh"],
-        namespace=os.getenv("TEAM") if os.getenv("TEAM") else namespace,
+        namespace=namespace,
         task_id=name,
         startup_timeout_seconds=startup_timeout_seconds,
         is_delete_operator_pod=delete_on_finish,
         image=os.getenv("KNADA_NOTEBOOK_OP_IMAGE",
                         "ghcr.io/navikt/knada-airflow:2022-10-14-8ec3b2c"),
+        executor_config={
+            "pod_override": client.V1Pod(
+                metadata=client.V1ObjectMeta(annotations={"allowlist": allowlist_str})
+            )
+        },
         env_vars=env_vars,
         do_xcom_push=do_xcom_push,
         volume_mounts=[
-            VolumeMount(
-                name="dags-data", mount_path=POD_WORKSPACE_DIR, sub_path=None, read_only=False
+            V1VolumeMount(
+                name="dags-data",
+                mount_path=POD_WORKSPACE_DIR,
+                sub_path=None,
+                read_only=False
             ),
-            VolumeMount(
+            V1VolumeMount(
                 name="ca-bundle-pem",
                 mount_path=CA_BUNDLE_PATH,
                 read_only=True,
@@ -112,27 +129,25 @@ def create_knada_nb_pod_operator(
         ],
         service_account_name=os.getenv("TEAM", "airflow"),
         volumes=[
-            Volume(name="dags-data", configs={}),
-            Volume(
-                name="airflow-git-secret",
-                configs={
-                    "secret": {
-                        "defaultMode": 448,
-                        "secretName": os.getenv("K8S_GIT_CLONE_SECRET", "github-app-secret"),
-                    }
-                },
+            V1Volume(
+                name="dags-data"
             ),
-            Volume(
+            V1Volume(
+                name="airflow-git-secret",
+                secret=V1SecretVolumeSource(
+                    default_mode=448,
+                    secret_name=os.getenv("K8S_GIT_CLONE_SECRET", "github-app-secret"),
+                )
+            ),
+            V1Volume(
                 name="ca-bundle-pem",
-                configs={
-                    "configMap": {
-                        "defaultMode": 420,
-                        "name": "ca-bundle-pem"
-                    }
-                }
+                config_map=V1ConfigMapVolumeSource(
+                    default_mode=420,
+                    name="ca-bundle-pem",
+                )
             ),
         ],
-        resources=resources,
+        container_resources=resources,
         retries=retries,
         on_success_callback=on_success_callback,
         retry_delay=retry_delay,
@@ -148,14 +163,15 @@ def create_knada_python_pod_operator(
     email: str = None,
     slack_channel: str = None,
     branch: str = "master",
-    resources: dict = None,
+    resources: client.V1ResourceRequirements = None,
     retries: int = 3,
     extra_envs: dict = None,
     delete_on_finish: bool = True,
     startup_timeout_seconds: int = 360,
     retry_delay: timedelta = timedelta(seconds=5),
     nls_lang: str = "NORWEGIAN_NORWAY.AL32UTF8",
-    do_xcom_push: bool = False
+    do_xcom_push: bool = False,
+    allowlist: list = [],
 ):
     """ Factory function for creating KubernetesPodOperator for executing knada python scripts
 
@@ -175,6 +191,7 @@ def create_knada_python_pod_operator(
     :param retry_delay: timedelta: Time inbetween retries, default 5 seconds
     :param nls_lang: str: Configure locale and character sets with NLS_LANG environment variable in k8s pod, defaults to Norwegian
     :param do_xcom_push: bool: Enable xcom push of content in file '/airflow/xcom/return.json'
+    :param allowlist: list: list of hosts and port the task needs to reach on the format host:port
     :return: KubernetesPodOperator
     """
 
@@ -183,20 +200,27 @@ def create_knada_python_pod_operator(
         "NOTEBOOK_NAME": Path(script_path).name,
         "TZ": os.environ["TZ"],
         "REQUESTS_CA_BUNDLE": CA_BUNDLE_PATH,
-        "NLS_LANG": nls_lang
+        "NLS_LANG": nls_lang,
+        "KNADA_TEAM_SECRET": os.environ["KNADA_TEAM_SECRET"]
     }
 
+    allowlist_str = "hooks.slack.com"
+
+    if len(allowlist):
+        allowlist_str += "," + ",".join(allowlist)
+
+    namespace = namespace if namespace else os.getenv("NAMESPACE")
+
     if extra_envs:
         env_vars = dict(env_vars, **extra_envs)
 
     def on_failure(context):
         if email:
-            send_email = create_email_notification(email, name, namespace, dag)
+            send_email = create_email_notification(dag._dag_id, email, name, namespace, dag)
             send_email.execute(context)
 
         if slack_channel:
-            slack_notification = create_slack_notification(
-                slack_channel, name, namespace)
+            slack_notification = create_slack_notification(dag._dag_id, slack_channel, name, namespace)
             slack_notification.execute(context)
 
     return KubernetesPodOperator(
@@ -208,17 +232,25 @@ def create_knada_python_pod_operator(
         startup_timeout_seconds=startup_timeout_seconds,
         name=name,
         cmds=["/bin/bash", "/execute_python.sh"],
-        namespace=os.getenv("TEAM") if os.getenv("TEAM") else namespace,
+        namespace=namespace,
         task_id=name,
         is_delete_operator_pod=delete_on_finish,
         image=os.getenv("KNADA_PYTHON_POD_OP_IMAGE",
                         "ghcr.io/navikt/knada-airflow:2022-05-25-bd8c92b"),
+        executor_config={
+            "pod_override": client.V1Pod(
+                metadata=client.V1ObjectMeta(annotations={"allowlist": allowlist_str})
+            )
+        },
         env_vars=env_vars,
         volume_mounts=[
-            VolumeMount(
-                name="dags-data", mount_path=POD_WORKSPACE_DIR, sub_path=None, read_only=False
+            V1VolumeMount(
+                name="dags-data",
+                mount_path=POD_WORKSPACE_DIR,
+                sub_path=None,
+                read_only=False
             ),
-            VolumeMount(
+            V1VolumeMount(
                 name="ca-bundle-pem",
                 mount_path=CA_BUNDLE_PATH,
                 read_only=True,
@@ -227,27 +259,25 @@ def create_knada_python_pod_operator(
         ],
         service_account_name=os.getenv("TEAM", "airflow"),
         volumes=[
-            Volume(name="dags-data", configs={}),
-            Volume(
-                name="airflow-git-secret",
-                configs={
-                    "secret": {
-                        "defaultMode": 448,
-                        "secretName": os.getenv("K8S_GIT_CLONE_SECRET", "github-app-secret"),
-                    }
-                },
+            V1Volume(
+                name="dags-data"
             ),
-            Volume(
+            V1Volume(
+                name="airflow-git-secret",
+                secret=V1SecretVolumeSource(
+                    default_mode=448,
+                    secret_name=os.getenv("K8S_GIT_CLONE_SECRET", "github-app-secret"),
+                )
+            ),
+            V1Volume(
                 name="ca-bundle-pem",
-                configs={
-                    "configMap": {
-                        "defaultMode": 420,
-                        "name": "ca-bundle-pem"
-                    }
-                }
+                config_map=V1ConfigMapVolumeSource(
+                    default_mode=420,
+                    name="ca-bundle-pem",
+                )
             ),
         ],
-        resources=resources,
+        container_resources=resources,
         retries=retries,
         retry_delay=retry_delay,
         do_xcom_push=do_xcom_push,
